#!/bin/bash
# Install iPerf3 on RHEL/Rocky/CentOS systems
set -euo pipefail

### PROGRESS: Installing iPerf3
echo "=== Installing iPerf3 ==="
dnf install -y -q iperf3

### PROGRESS: Verifying installation
echo "=== iPerf3 installed ==="
iperf3 --version
