#!/bin/bash
# Install iPerf3 on Debian/Ubuntu systems
set -euo pipefail

### PROGRESS: Installing iPerf3
echo "=== Installing iPerf3 ==="
apt-get update -qq
apt-get install -y -qq iperf3

### PROGRESS: Verifying installation
echo "=== iPerf3 installed ==="
iperf3 --version
